@@ -466,7 +466,16 @@ def get_features(more_features, tmpdir: str, use_ipfs: bool) -> EvaluatorFeature
     features["processor_free_percent"] = int(100.0 - f)
     features["p1"] = True
 
-    disk = psutil.disk_usage(tmpdir)
+    if not os.path.exists(tmpdir):
+        try:
+            os.makedirs(tmpdir, exist_ok=True)
+        except:
+            pass
+
+    if not os.path.exists(tmpdir):
+        disk = psutil.disk_usage(tmpdir)
+    else:
+        disk = psutil.disk_usage(os.getcwd())
 
     features["disk_total_mb"] = disk.total / (1024 * 1024)
     features["disk_available_mb"] = disk.free / (1024 * 1024)
