@@ -13,13 +13,6 @@ from typing import cast
 import termcolor
 import yaml
 from docker import DockerClient
-from zuper_commons.fs import mkdirs_thread_safe, read_ustring_from_utf8_file, write_ustring_to_utf8_file
-from zuper_commons.text import indent
-from zuper_commons.timing import now_utc
-from zuper_commons.types import ZValueError
-
-from dt_shell import ConfigNotPresent
-from dt_shell.config import get_shell_config_default, read_shell_config
 from duckietown_build_utils import (
     BuildFailed,
     DockerCompleteImageName,
@@ -38,12 +31,20 @@ from duckietown_challenges import (
     dtserver_get_compatible_challenges,
     get_challenge_description,
     get_registry_info,
+    InvalidConfiguration,
     List,
     read_submission_info,
     SubmissionID,
     traceback,
 )
 from duckietown_challenges.utils import tag_from_date
+
+from dt_shell import ConfigNotPresent
+from dt_shell.config import get_shell_config_default, read_shell_config
+from zuper_commons.fs import mkdirs_thread_safe, read_ustring_from_utf8_file, write_ustring_to_utf8_file
+from zuper_commons.text import indent
+from zuper_commons.timing import now_utc
+from zuper_commons.types import ZValueError
 from . import logger
 from .exceptions import UserError
 from .runner import run_single
@@ -89,6 +90,7 @@ def runner_local_main_(args: List[str] = None, token: str = None):
     group.add_argument("--no-cache", action="store_true", default=False, help="")
 
     group.add_argument("--no-build", action="store_true", default=False, help="")
+
     group.add_argument("--no-pull", action="store_true", default=False, help="")
     group.add_argument("--dev", action="store_true", default=False, help="Activate development mode")
     group.add_argument("--output", default=None)
@@ -102,6 +104,8 @@ def runner_local_main_(args: List[str] = None, token: str = None):
     parser.add_argument("--debug", default=False, action="store_true", help="Verbose output")
 
     group.add_argument("-C", dest="change", default=None)
+    group.add_argument("--image", default=None, help="pass explicit image name")
+    group.add_argument("--config", default="submission.yaml", help="Read from the given configuration file.")
 
     evaluator_name = "local"
 
@@ -126,16 +130,20 @@ def runner_local_main_(args: List[str] = None, token: str = None):
 
     try:
         shell_config = read_shell_config()
-    except (ConfigNotPresent) as e:
+    except ConfigNotPresent as e:
         msg = f"Cannot find shell config: {e}"
         logger.warning(msg)
         shell_config = get_shell_config_default()
     if token is None:
         token = shell_config.token_dt1
 
-    path = "."
+    config_filename = parsed.config
+    if not os.path.exists(config_filename):
+        msg = f'Could not find configuration file "{config_filename}".'
+        raise InvalidConfiguration(msg)
+
+    sub_info = read_submission_info(config_filename)
 
-    sub_info = read_submission_info(path)
     ri = get_registry_info(token=token, impersonate=parsed.impersonate)
     registry = cast(DockerRegistryName, ri.registry)
     compat = dtserver_get_compatible_challenges(
@@ -148,11 +156,6 @@ def runner_local_main_(args: List[str] = None, token: str = None):
         msg = "There are no compatible challenges with submission protocols."
         raise UserError(msg, protocols=sub_info.protocols)
 
-    dockerfile = os.path.join(path, "Dockerfile")
-    if not os.path.exists(dockerfile):
-        msg = f'I expected to find the file "{dockerfile}".'
-        raise Exception(msg)
-
     # client = check_docker_environment()
 
     no_cache = parsed.no_cache
@@ -205,15 +208,22 @@ For example, you could try:
     # logger.debug(cd=cd)
 
     # tag = cast(DockerCompleteImageName, "dummy-org/dummy-repo")
-    # TODO: change the build procedure
     credentials = cast(DockerCredentials, shell_config.docker_credentials)
-    solution_container = submission_build3(
-        credentials=credentials, registry=registry, no_cache=no_cache, pull=do_pull
-    )
 
-    # image = build_image(
-    #     client, tag=tag, path=path, dockerfile=dockerfile, no_cache=no_cache, no_build=no_build,
-    # )
+    # TODO: change the build procedure
+    if parsed.image is not None:
+        solution_container = parsed.image
+        logger.info(f"Using image {solution_container} passed from --image")
+    else:
+        path = "."
+        dockerfile = os.path.join(path, "Dockerfile")
+        if not os.path.exists(dockerfile):
+            msg = f'I expected to find the file "{dockerfile}".'
+            raise Exception(msg)
+
+        solution_container = submission_build3(
+            credentials=credentials, registry=registry, no_cache=no_cache, pull=do_pull
+        )
 
     caching = False
     # solution_container = tag
